@@ -2,12 +2,12 @@ import argparse
 
 from sqlvalidator import file_formatter
 
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 
 
 def _main() -> None:
     parser = argparse.ArgumentParser(
-        description="SQL formatting (and basic schema less validation soon)"
+        description="SQL formatting and basic schemaless validation"
     )
     parser.add_argument("SRC", help="input. Either a file or a folder.")
     parser.add_argument(
