@@ -1,8 +1,11 @@
+from sqlvalidator.grammar.lexer import SQLStatementParser, to_tokens, ParsingError
+
+
 class SQLQuery:
     def __init__(self, sql: str):
         self.sql = sql
         self.validated = False
-        self.errors: list = []
+        self.errors = []
 
     def is_valid(self) -> bool:
         if not self.validated:
@@ -11,7 +14,11 @@ class SQLQuery:
 
     def _validate(self):
         self.validated = True
-        # TODO: to be implemented
+        try:
+            select_statement = SQLStatementParser.parse(to_tokens(self.sql))
+            self.errors = select_statement.validate()
+        except ParsingError as ex:
+            self.errors.append(str(ex))
 
 
 def parse(sql: str) -> SQLQuery:
